from django import forms

from events.models import Event

class EventForm(forms.ModelForm):
    class Meta:
        model = Event
        widgets = {
                'duration': forms.TextInput(),
                }

